# candlestick

## Objects

 * <span class="badge object-type-enum"></span> [CandleStyle](./object-CandleStyle.md)
 * <span class="badge object-type-class"></span> [CandlestickColors](./object-CandlestickColors.md)
 * <span class="badge object-type-class"></span> [CandlestickFieldMap](./object-CandlestickFieldMap.md)
 * <span class="badge object-type-enum"></span> [ColorStrategy](./object-ColorStrategy.md)
 * <span class="badge object-type-ref"></span> [FieldConfig](./object-FieldConfig.md)
 * <span class="badge object-type-class"></span> [Options](./object-Options.md)
 * <span class="badge object-type-enum"></span> [VizDisplayMode](./object-VizDisplayMode.md)
## Builders

 * <span class="badge builder"></span> [CandlestickColors](./builder-CandlestickColors.md)
 * <span class="badge builder"></span> [CandlestickFieldMap](./builder-CandlestickFieldMap.md)
 * <span class="badge builder"></span> [Panel](./builder-Panel.md)
